==> gnome_applets-2.10.1-i386-P2.tgz: install/doinst.sh <==
( cd usr/share/doc/gnome-applets-2.10.1 ; rm -rf build )
( cd usr/share/doc/gnome-applets-2.10.1 ; ln -sf /usr/src/garnome-Ptgz-kit build )
#%% begin initialize gnome_applets-2.10.1-i386-P2
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -q || exit 1
fi
GCONFTOOL=/usr/bin/gconftool-2
if [ ! -x $GCONFTOOL ]; then
  exit 1
fi
GCONF_CONFIG_SOURCE=`$GCONFTOOL --get-default-source`
export GCONF_CONFIG_SOURCE
GCONF_DIR=/usr/etc/gconf
SCHEMA_DIR=$GCONF_DIR/schemas
SCHEMA_FILES=" \
  battstat.schemas \
  charpick.schemas \
  cpufreq-applet.schemas \
  drivemount.schemas \
  geyes.schemas \
  gswitchit.schemas \
  gtik.schemas \
  gweather.schemas \
  mini-commander-global.schemas \
  mini-commander.schemas \
  mixer.schemas \
  multiload.schemas \
  stickynotes.schemas \
  "
for s in $SCHEMA_FILES; do
  $GCONFTOOL --makefile-install-rule $SCHEMA_DIR/$s > /dev/null
done
# GCONFTOOL and GCONF_DIR is already set.
/usr/libexec/gnome-applets/mc-install-default-macros
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t string /apps/stickynotes_applet/defaults/font 'FS Gothic 10'
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t string /apps/stickynotes_applet/settings/date_format '%D'
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t bool /apps/stickynotes_applet/settings/use_system_color false
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t bool /apps/stickynotes_applet/settings/use_system_font false
#%% end

==> gnome_applets-2.12.2-i386-P2.tgz: install/doinst.sh <==
( cd usr/share/doc/gnome-applets-2.12.2 ; rm -rf build )
( cd usr/share/doc/gnome-applets-2.12.2 ; ln -sf /usr/src/garnome-Ptgz-kit build )
#%% begin initialize gnome_applets-2.12.2-i386-P2
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -q || exit 1
fi
GCONFTOOL=/usr/bin/gconftool-2
if [ ! -x $GCONFTOOL ]; then
  exit 1
fi
GCONF_CONFIG_SOURCE=`$GCONFTOOL --get-default-source`
export GCONF_CONFIG_SOURCE
GCONF_DIR=/usr/etc/gconf
SCHEMA_DIR=$GCONF_DIR/schemas
SCHEMA_FILES=" \
  battstat.schemas \
  charpick.schemas \
  cpufreq-applet.schemas \
  drivemount.schemas \
  geyes.schemas \
  gswitchit.schemas \
  gtik.schemas \
  gweather.schemas \
  mini-commander-global.schemas \
  mini-commander.schemas \
  mixer.schemas \
  multiload.schemas \
  stickynotes.schemas \
  "
for s in $SCHEMA_FILES; do
  $GCONFTOOL --makefile-install-rule $SCHEMA_DIR/$s > /dev/null
done
# GCONFTOOL and GCONF_DIR is already set.
/usr/libexec/gnome-applets/mc-install-default-macros
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t string /apps/stickynotes_applet/defaults/font 'Monospace 10'
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t string /apps/stickynotes_applet/settings/date_format '%D'
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t bool /apps/stickynotes_applet/settings/use_system_color false
$GCONFTOOL --direct -s --config-source xml:readwrite:/$GCONF_DIR/gconf.xml.defaults/ -t bool /apps/stickynotes_applet/settings/use_system_font false
#%% end
